@@ -20,24 +20,20 @@
 
 #include <config.h>
 
+#include <libgnomevfs/gnome-vfs-utils.h>
 
 #include "procman.h"
 #include "infoview.h"
 #include "interface.h"
 #include "util.h"
-#if 0
-#include "procdialogs.h"
-#include "memmaps.h"
-#include "e-clipped-label.h"
-#endif
 
-GtkWidget *infobox;
-GtkWidget *cmd_label;
-GtkWidget *status_label;
-GtkWidget *nice_label;
-GtkWidget *memtotal_label;
-GtkWidget *memrss_label;
-GtkWidget *memshared_label;
+
+static GtkWidget *cmd_label = NULL;
+static GtkWidget *status_label = NULL;
+static GtkWidget *nice_label = NULL;
+static GtkWidget *memtotal_label = NULL;
+static GtkWidget *memrss_label = NULL;
+static GtkWidget *memshared_label = NULL;
 
 static GtkWidget *
 make_title_label (const char *text)
@@ -56,10 +52,10 @@ make_title_label (const char *text)
 }
 
 GtkWidget *
-infoview_create (ProcData *data)
+infoview_create (ProcData *procdata)
 {
-	ProcData *procdata = data;
 	GtkWidget *infobox;
+
 	GtkWidget *main_hbox;
 	GtkWidget *info_table, *mem_table;
 	GtkWidget *label;
@@ -67,14 +63,14 @@ infoview_create (ProcData *data)
 	GtkWidget *info_title, *info_box;
 	GtkWidget *mem_title, *mem_box;
 	GtkWidget *spacer, *info_hbox, *mem_hbox;
-	
+
 	infobox = gtk_vbox_new (FALSE, 0);
-		
+
 	main_hbox = gtk_hbox_new (FALSE, 18);
 	gtk_box_pack_start (GTK_BOX (infobox), main_hbox, FALSE, TRUE, 0);
-	
+
 	/* The Process Info Area */
-	
+
 	info_box = gtk_vbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (main_hbox), info_box, TRUE, TRUE, 0);
 
@@ -91,32 +87,32 @@ infoview_create (ProcData *data)
 	gtk_table_set_row_spacings (GTK_TABLE (info_table), 6);
 	gtk_table_set_col_spacings (GTK_TABLE (info_table), 12);
 	gtk_box_pack_start (GTK_BOX (info_hbox), info_table, FALSE, FALSE, 0);
-	
+
 	label = gtk_label_new (_("Command:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (info_table), label, 0, 1, 0, 1, GTK_FILL, 
+	gtk_table_attach (GTK_TABLE (info_table), label, 0, 1, 0, 1, GTK_FILL,
 			  0, 0, 0);
 	label = gtk_label_new (_("Status:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (info_table), label, 0, 1, 1, 2, GTK_FILL, 
+	gtk_table_attach (GTK_TABLE (info_table), label, 0, 1, 1, 2, GTK_FILL,
 			  0, 0, 0);
 	label = gtk_label_new (_("Priority:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (info_table), label, 0, 1, 2, 3, GTK_FILL, 
+	gtk_table_attach (GTK_TABLE (info_table), label, 0, 1, 2, 3, GTK_FILL,
 			  0, 0, 0);
-	
+
 	cmd_label = gtk_label_new ("");
 	gtk_misc_set_alignment (GTK_MISC (cmd_label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (info_table), cmd_label, 1, 2, 0, 1, GTK_FILL, 
+	gtk_table_attach (GTK_TABLE (info_table), cmd_label, 1, 2, 0, 1, GTK_FILL,
 			  0, 0, 0);
-	
+
 	status_label = gtk_label_new ("");
 	gtk_misc_set_alignment (GTK_MISC (status_label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (info_table), status_label, 1, 2, 1, 2, GTK_FILL, 
+	gtk_table_attach (GTK_TABLE (info_table), status_label, 1, 2, 1, 2, GTK_FILL,
 			  0, 0, 0);
 	nice_label = gtk_label_new ("");
 	gtk_misc_set_alignment (GTK_MISC (nice_label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (info_table), nice_label, 1, 2, 2, 3, GTK_FILL, 
+	gtk_table_attach (GTK_TABLE (info_table), nice_label, 1, 2, 2, 3, GTK_FILL,
 			  0, 0, 0);
 
 	/*The Memory usage Area*/
@@ -132,43 +128,43 @@ infoview_create (ProcData *data)
 
 	spacer = gtk_label_new ("    ");
 	gtk_box_pack_start (GTK_BOX (mem_hbox), spacer, FALSE, FALSE, 0);
-	
+
 	mem_table = gtk_table_new (3, 2, FALSE);
 	gtk_table_set_row_spacings (GTK_TABLE (mem_table), 6);
 	gtk_table_set_col_spacings (GTK_TABLE (mem_table), 12);
 	gtk_box_pack_start (GTK_BOX (mem_hbox), mem_table, FALSE, FALSE, 0);
-	
+
 	label = gtk_label_new (_("Total:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (mem_table), label, 0, 1, 0, 1, GTK_FILL, 
+	gtk_table_attach (GTK_TABLE (mem_table), label, 0, 1, 0, 1, GTK_FILL,
 			  0, 0, 0);
 	label = gtk_label_new (_("RSS:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (mem_table), label, 0, 1, 1, 2, GTK_FILL, 
+	gtk_table_attach (GTK_TABLE (mem_table), label, 0, 1, 1, 2, GTK_FILL,
 			  0, 0, 0);
 	label = gtk_label_new (_("Shared:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (mem_table), label, 0, 1, 2, 3, GTK_FILL, 
+	gtk_table_attach (GTK_TABLE (mem_table), label, 0, 1, 2, 3, GTK_FILL,
 			  0, 0, 0);
-			  
+
 	memtotal_label = gtk_label_new ("");
 	gtk_misc_set_alignment (GTK_MISC (memtotal_label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (mem_table), memtotal_label, 1, 2, 0, 1, GTK_FILL, 
+	gtk_table_attach (GTK_TABLE (mem_table), memtotal_label, 1, 2, 0, 1, GTK_FILL,
 			  0, 0, 0);
 	memrss_label = gtk_label_new ("");
 	gtk_misc_set_alignment (GTK_MISC (memrss_label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (mem_table), memrss_label, 1, 2, 1, 2, GTK_FILL, 
+	gtk_table_attach (GTK_TABLE (mem_table), memrss_label, 1, 2, 1, 2, GTK_FILL,
 			  0, 0, 0);
 	memshared_label = gtk_label_new ("");
 	gtk_misc_set_alignment (GTK_MISC (memshared_label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (mem_table), memshared_label, 1, 2, 2, 3, GTK_FILL, 
+	gtk_table_attach (GTK_TABLE (mem_table), memshared_label, 1, 2, 2, 3, GTK_FILL,
 			  0, 0, 0);
-			  
+
 	procdata->infobox = infobox;
 
-		
+
 	return infobox;
-	
+
 
 }
 
@@ -178,18 +174,17 @@ infoview_update (ProcData *data)
 	ProcData *procdata = data;
 	ProcInfo *info;
 	gchar *string;
-	gchar *command;
 
 	if (!procdata->selected_process) {
 		update_sensitivity (procdata, FALSE);
 		return;
 	}
 
-	info = procdata->selected_process;	
+	info = procdata->selected_process;
 
 	gtk_label_set_text (GTK_LABEL (cmd_label), info->name);
 	gtk_label_set_text (GTK_LABEL (status_label), info->status);
-	
+
 	if (info->nice < -7)
 		string = g_strdup_printf (_("Very high - nice %d"), info->nice);
 	else if (info->nice < -2)
@@ -201,16 +196,17 @@ infoview_update (ProcData *data)
 	else
 		string = g_strdup_printf (_("Very low - nice %d"), info->nice);
 	gtk_label_set_text (GTK_LABEL (nice_label), string);
-	g_free (string); 
-	string = get_size_string (info->mem);
+	g_free (string);
+
+	string = gnome_vfs_format_file_size_for_display (info->mem);
 	gtk_label_set_text (GTK_LABEL (memtotal_label), string);
 	g_free (string);
-	string = get_size_string (info->memrss);
+
+	string = gnome_vfs_format_file_size_for_display (info->memrss);
 	gtk_label_set_text (GTK_LABEL (memrss_label), string);
 	g_free (string);
-	string = get_size_string (info->memshared);
+
+	string = gnome_vfs_format_file_size_for_display (info->memshared);
 	gtk_label_set_text (GTK_LABEL (memshared_label), string);
 	g_free (string);
-	
-	
 }
