@@ -352,7 +352,7 @@ create_sys_view (ProcData *procdata)
 	gtk_container_set_border_width (GTK_CONTAINER (vpane), 6);
 
 	vbox = gtk_vbox_new (FALSE, 18);
-	gtk_paned_pack1 (GTK_PANED (vpane), vbox, TRUE, FALSE);
+	gtk_paned_pack1 (GTK_PANED (vpane), vbox, FALSE, FALSE);
 
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
 
@@ -540,12 +540,12 @@ create_sys_view (ProcData *procdata)
 
 	model = gtk_tree_store_new (10,
 				    GDK_TYPE_PIXBUF,
-				    G_TYPE_STRING, // device name
-				    G_TYPE_STRING, // directory
-				    G_TYPE_STRING, // type
-				    G_TYPE_STRING, // total
-				    G_TYPE_STRING, // free
-				    G_TYPE_STRING, // used
+				    G_TYPE_STRING, /* device name */
+				    G_TYPE_STRING, /* directory */
+				    G_TYPE_STRING, /* type */
+				    G_TYPE_STRING, /* total */
+				    G_TYPE_STRING, /* free */
+				    G_TYPE_STRING, /* used */
 				    G_TYPE_FLOAT,
 				    G_TYPE_FLOAT,
 				    G_TYPE_FLOAT);
