@@ -23,7 +23,6 @@
 
 #include <signal.h>
 #include <string.h>
-#include <libgnomesu/libgnomesu.h>
 #include "procdialogs.h"
 #include "favorites.h"
 #include "proctable.h"
@@ -68,6 +67,7 @@ procdialog_create_hide_dialog (ProcData *data)
 						   message);
        g_free (message);
 
+       /* FIXME: View menu -> Edit menu */
        /*translators: secondary alert messagex*/
        message = g_strdup_printf (_("Hidden processes are no longer visible "
 				    "in the process list. You can re-enable "
@@ -301,31 +301,6 @@ prefs_dialog_button_pressed (GtkDialog *dialog, gint id, gpointer data)
 	prefs_dialog = NULL;
 }
 
-static void
-show_tree_toggled (GtkToggleButton *button, gpointer data)
-{
-	ProcData *procdata = data;
-	GConfClient *client = procdata->client;
-	gboolean toggled;
-	
-	toggled = gtk_toggle_button_get_active (button);
-	gconf_client_set_bool (client, "/apps/procman/show_tree", toggled, NULL);
-
-}
-
-static void
-show_threads_toggled (GtkToggleButton *button, gpointer data)
-{
-	ProcData *procdata = data;
-	GConfClient *client = procdata->client;
-	
-	gboolean toggled;
-	
-	toggled = gtk_toggle_button_get_active (button);
-	
-	gconf_client_set_bool (client, "/apps/procman/show_threads", toggled, NULL);
-		
-}
 
 static void
 show_kill_dialog_toggled (GtkToggleButton *button, gpointer data)
@@ -410,18 +385,6 @@ update_disks_update_interval (GtkWidget *widget, GdkEventFocus *event, gpointer
 }
 
 
-static void
-proc_field_toggled (GtkToggleButton *button, gpointer data)
-{
-	GtkTreeViewColumn *column = data;
-	gboolean toggled;
-	
-	toggled = gtk_toggle_button_get_active (button);
-
-	gtk_tree_view_column_set_visible (column, toggled);
-	
-}
-
 static void
 field_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer data)
 {
@@ -799,14 +762,6 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), 1);
 }
 
-static void
-entry_activate_cb (GtkEntry *entry, gpointer data)
-{
-	GtkDialog *dialog = GTK_DIALOG (data);
-	
-	gtk_dialog_response (dialog, 100);
-	
-}	
 
 /*
 ** type determines whether if dialog is for killing process (type=0) or renice (type=other).
@@ -815,13 +770,36 @@ entry_activate_cb (GtkEntry *entry, gpointer data)
 void procdialog_create_root_password_dialog (gint type, ProcData *procdata, gint pid, 
 					     gint extra_value, gchar *text)
 {
-	gchar *command;
+	GModule *mod;
+	gpointer gnomesu_exec;
+	gboolean has_libgnomesu = FALSE;
+	typedef gboolean (*GnomesuExecFunc) (char *commandline);
 
-	if (type == 0)
-		command = g_strdup_printf ("kill -s %d %d", extra_value, pid);
-	else
-		command = g_strdup_printf ("renice %d %d", extra_value, pid);
-	gnomesu_exec (command);
-	g_free (command);
+	/* Attempt to use libgnomesu */
+	mod = g_module_open ("libgnomesu.so.0", G_MODULE_BIND_LAZY | G_MODULE_BIND_LOCAL);
+	if (mod) {
+		if (g_module_symbol (mod, "gnomesu_exec", &gnomesu_exec)) {
+			gchar *command;
+
+			has_libgnomesu = TRUE;
+			if (type == 0)
+				command = g_strdup_printf ("kill -s %d %d", extra_value, pid);
+			else
+				command = g_strdup_printf ("renice %d %d", extra_value, pid);
+			((GnomesuExecFunc) gnomesu_exec) (command);
+			g_free (command);
+		}
+
+		g_module_close (mod);
+	}
+
+	if (!has_libgnomesu) {
+		if (type == 0)
+			g_warning(_("Cannot kill process with pid %d with signal %d"),
+				  pid, extra_value);
+		else
+			g_warning(_("Cannot change the priority of process with pid %d to %d"),
+				  pid, extra_value);
+	}
 }
 
